# !/usr/bin/env python
# -*-coding=utf-8-*-

__all__ = ['_private_variable', 'public_teacher']

public_variable = "Hello, I am a public variable."

_private_variable = "Hi, I am a private variable."


def public_teacher():
    print("I am a public teacher, I am from JP.")


def _private_teacher():
    print("I am a private teacher, I am from CN.")

def test():
    print("this is test method")





from distutils.core import setup
# dependency_links = ['http://xxx/xmltodict', 'http://xxx/pycurl']

setup(
    name="strglee",
    version="1.0.1",
    description="This is a test of the setup",
    author="strglee",
    author_email="strglee@gmail.com",
    url="http://strglee.com",
    install_requires=['pycurl', 'xmltodict'],
    package_dir={"bar": "foobar"},
    packages=['qi', 'bar']
)
